@@ -1,3 +1,15 @@
+/* ddrvsy.f -- translated by f2c (version 20061008).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
+*/
+
 #include "f2c.h"
 #include "blaswrap.h"
 
@@ -11,7 +23,7 @@ struct {
 #define infoc_1 infoc_
 
 struct {
-    char srnamt[6];
+    char srnamt[32];
 } srnamc_;
 
 #define srnamc_1 srnamc_
@@ -37,11 +49,11 @@ static doublereal c_b49 = 0.;
     static char facts[1*2] = "F" "N";
 
     /* Format strings */
-    static char fmt_9999[] = "(1x,a6,\002, UPLO='\002,a1,\002', N =\002,i5"
+    static char fmt_9999[] = "(1x,a,\002, UPLO='\002,a1,\002', N =\002,i5"
 	    ",\002, type \002,i2,\002, test \002,i2,\002, ratio =\002,g12.5)";
-    static char fmt_9998[] = "(1x,a6,\002, FACT='\002,a1,\002', UPLO='\002,a"
-	    "1,\002', N =\002,i5,\002, type \002,i2,\002, test \002,i2,\002, "
-	    "ratio =\002,g12.5)";
+    static char fmt_9998[] = "(1x,a,\002, FACT='\002,a1,\002', UPLO='\002,"
+	    "a1,\002', N =\002,i5,\002, type \002,i2,\002, test \002,i2,\002,"
+	    " ratio =\002,g12.5)";
 
     /* System generated locals */
     address a__1[2];
@@ -293,7 +305,7 @@ static doublereal c_b49 = 0.;
 		dlatb4_(path, &imat, &n, &n, type__, &kl, &ku, &anorm, &mode, 
 			&cndnum, dist);
 
-		s_copy(srnamc_1.srnamt, "DLATMS", (ftnlen)6, (ftnlen)6);
+		s_copy(srnamc_1.srnamt, "DLATMS", (ftnlen)32, (ftnlen)6);
 		dlatms_(&n, &n, dist, iseed, type__, &rwork[1], &mode, &
 			cndnum, &anorm, &kl, &ku, uplo, &a[1], &lda, &work[1], 
 			 &info);
@@ -436,7 +448,7 @@ static doublereal c_b49 = 0.;
 
 /*                 Form an exact solution and set the right hand side. */
 
-		    s_copy(srnamc_1.srnamt, "DLARHS", (ftnlen)6, (ftnlen)6);
+		    s_copy(srnamc_1.srnamt, "DLARHS", (ftnlen)32, (ftnlen)6);
 		    dlarhs_(path, xtype, uplo, " ", &n, &n, &kl, &ku, nrhs, &
 			    a[1], &lda, &xact[1], &lda, &b[1], &lda, iseed, &
 			    info);
@@ -450,7 +462,7 @@ static doublereal c_b49 = 0.;
 
 /*                    Factor the matrix and solve the system using DSYSV. */
 
-			s_copy(srnamc_1.srnamt, "DSYSV ", (ftnlen)6, (ftnlen)
+			s_copy(srnamc_1.srnamt, "DSYSV ", (ftnlen)32, (ftnlen)
 				6);
 			dsysv_(uplo, &n, nrhs, &afac[1], &lda, &iwork[1], &x[
 				1], &lda, &work[1], &lwork, &info);
@@ -542,7 +554,7 @@ L120:
 /*                 Solve the system and compute the condition number and */
 /*                 error bounds using DSYSVX. */
 
-		    s_copy(srnamc_1.srnamt, "DSYSVX", (ftnlen)6, (ftnlen)6);
+		    s_copy(srnamc_1.srnamt, "DSYSVX", (ftnlen)32, (ftnlen)6);
 		    dsysvx_(fact, uplo, &n, nrhs, &a[1], &lda, &afac[1], &lda, 
 			     &iwork[1], &b[1], &lda, &x[1], &lda, &rcond, &
 			    rwork[1], &rwork[*nrhs + 1], &work[1], &lwork, &
